@@ -43,7 +43,7 @@
 #' Default is \code{rep(1, ncol(x))}.
 #' @param seed Random seed for cross-validation fold division.
 #' @param parallel Logical. Enable parallel parameter tuning or not,
-#' default is {FALSE}. To enable parallel tuning, load the
+#' default is \code{FALSE}. To enable parallel tuning, load the
 #' \code{doParallel} package and run \code{registerDoParallel()}
 #' with the number of CPU cores before calling this function.
 #' @param verbose Should we print out the estimation progress?
@@ -79,22 +79,21 @@
 #' msaenet.rmse(dat$y.te, msamnet.pred)
 #' plot(msamnet.fit)
 msamnet <- function(
-  x, y,
-  family = c("gaussian", "binomial", "poisson", "cox"),
-  init = c("mnet", "ridge"),
-  gammas = 3, alphas = seq(0.05, 0.95, 0.05),
-  tune = c("cv", "ebic", "bic", "aic"),
-  nfolds = 5L,
-  ebic.gamma = 1,
-  nsteps = 2L,
-  tune.nsteps = c("max", "ebic", "bic", "aic"),
-  ebic.gamma.nsteps = 1,
-  scale = 1,
-  eps = 1e-4, max.iter = 10000L,
-  penalty.factor.init = rep(1, ncol(x)),
-  seed = 1001, parallel = FALSE, verbose = FALSE) {
-
-  if (nsteps < 2L) stop("nsteps must be an integer >= 2")
+    x, y,
+    family = c("gaussian", "binomial", "poisson", "cox"),
+    init = c("mnet", "ridge"),
+    gammas = 3, alphas = seq(0.05, 0.95, 0.05),
+    tune = c("cv", "ebic", "bic", "aic"),
+    nfolds = 5L,
+    ebic.gamma = 1,
+    nsteps = 2L,
+    tune.nsteps = c("max", "ebic", "bic", "aic"),
+    ebic.gamma.nsteps = 1,
+    scale = 1,
+    eps = 1e-4, max.iter = 10000L,
+    penalty.factor.init = rep(1, ncol(x)),
+    seed = 1001, parallel = FALSE, verbose = FALSE) {
+  if (nsteps < 2L) stop("`nsteps` must be an integer >= 2.", call. = FALSE)
 
   family <- match.arg(family)
   init <- match.arg(init)
@@ -139,9 +138,7 @@ msamnet <- function(
       penalty.factor = penalty.factor.init
     )
 
-    if (.df(model.list[[1L]]) < 0.5) {
-      stop("Null model produced by the full fit (all coefficients are zero). Please try a different parameter setting.")
-    }
+    if (.df(model.list[[1L]]) < 0.5) stop(message.null.model, call. = FALSE)
 
     bhat <- .coef.ncvreg(model.list[[1L]], nvar)
   }
@@ -170,9 +167,7 @@ msamnet <- function(
       penalty.factor = penalty.factor.init
     )
 
-    if (.df(model.list[[1L]]) < 0.5) {
-      stop("Null model produced by the full fit (all coefficients are zero). Please try a different parameter setting.")
-    }
+    if (.df(model.list[[1L]]) < 0.5) stop(message.null.model, call. = FALSE)
 
     bhat <- as.matrix(model.list[[1L]][["beta"]])
   }
@@ -212,9 +207,7 @@ msamnet <- function(
       penalty.factor = adapen.list[[i]]
     )
 
-    if (.df(model.list[[i + 1L]]) < 0.5) {
-      stop("Null model produced by the full fit (all coefficients are zero). Please try a different parameter setting.")
-    }
+    if (.df(model.list[[i + 1L]]) < 0.5) stop(message.null.model, call. = FALSE)
 
     bhat <- .coef.ncvreg(model.list[[i + 1L]], nvar)
     if (all(bhat == 0)) bhat <- rep(.Machine$double.eps * 2, length(bhat))
